@@ -25,7 +25,7 @@ impl ListChunked {
     }
 
     pub fn to_logical(&mut self, inner_dtype: DataType) {
-        assert_eq!(inner_dtype.to_physical(), self.inner_dtype());
+        debug_assert_eq!(inner_dtype.to_physical(), self.inner_dtype());
         let fld = Arc::make_mut(&mut self.field);
         fld.coerce(DataType::List(Box::new(inner_dtype)))
     }
