@@ -3,7 +3,7 @@ use crate::prelude::*;
 impl Series {
     /// Extend with a constant value.
     pub fn extend_constant(&self, value: AnyValue, n: usize) -> PolarsResult<Self> {
-        let s = Series::from_any_values("", &[value]).unwrap();
+        let s = Series::from_any_values("", &[value], false).unwrap();
         let s = s.cast(self.dtype())?;
         let to_append = s.new_from_index(0, n);
 
