@@ -133,7 +133,7 @@
 //!         col("column_a")
 //!         // apply a custom closure Series => Result<Series>
 //!         .map(|_s| {
-//!             Ok(Series::new("", &[6.0f32, 6.0, 6.0, 6.0, 6.0]))
+//!             Ok(Some(Series::new("", &[6.0f32, 6.0, 6.0, 6.0, 6.0])))
 //!         },
 //!         // return type of the closure
 //!         GetOutput::from_type(DataType::Float64)).alias("new_column")
@@ -182,6 +182,7 @@
 //!      )
 //! }
 //! ```
+#![allow(ambiguous_glob_reexports)]
 #![cfg_attr(docsrs, feature(doc_auto_cfg))]
 extern crate core;
 
