@@ -1,3 +1,5 @@
+//! # Polars SQL
+#![deny(missing_docs)]
 mod context;
 mod functions;
 mod sql_expr;
@@ -21,7 +23,7 @@ mod test {
     #[test]
     fn test_simple_select() -> PolarsResult<()> {
         let df = create_sample_df()?;
-        let mut context = SQLContext::try_new()?;
+        let mut context = SQLContext::new();
         context.register("df", df.clone().lazy());
         let df_sql = context
             .execute(
@@ -46,7 +48,7 @@ mod test {
     #[test]
     fn test_nested_expr() -> PolarsResult<()> {
         let df = create_sample_df()?;
-        let mut context = SQLContext::try_new()?;
+        let mut context = SQLContext::new();
         context.register("df", df.clone().lazy());
         let df_sql = context
             .execute(r#"SELECT * FROM df WHERE (a > 3)"#)?
@@ -59,7 +61,7 @@ mod test {
     #[test]
     fn test_groupby_simple() -> PolarsResult<()> {
         let df = create_sample_df()?;
-        let mut context = SQLContext::try_new()?;
+        let mut context = SQLContext::new();
         context.register("df", df.clone().lazy());
         let df_sql = context
             .execute(
@@ -104,7 +106,7 @@ mod test {
     #[test]
     fn test_cast_exprs() {
         let df = create_sample_df().unwrap();
-        let mut context = SQLContext::try_new().unwrap();
+        let mut context = SQLContext::new();
         context.register("df", df.clone().lazy());
         let sql = r#"
             SELECT 
@@ -130,7 +132,7 @@ mod test {
     #[test]
     fn test_literal_exprs() {
         let df = create_sample_df().unwrap();
-        let mut context = SQLContext::try_new().unwrap();
+        let mut context = SQLContext::new();
         context.register("df", df.clone().lazy());
         let sql = r#"
             SELECT 
@@ -158,7 +160,7 @@ mod test {
     #[test]
     fn test_prefixed_column_names() {
         let df = create_sample_df().unwrap();
-        let mut context = SQLContext::try_new().unwrap();
+        let mut context = SQLContext::new();
         context.register("df", df.clone().lazy());
         let sql = r#"
             SELECT 
@@ -177,7 +179,7 @@ mod test {
     #[test]
     fn test_prefixed_column_names_2() {
         let df = create_sample_df().unwrap();
-        let mut context = SQLContext::try_new().unwrap();
+        let mut context = SQLContext::new();
         context.register("df", df.clone().lazy());
         let sql = r#"
             SELECT 
@@ -195,7 +197,7 @@ mod test {
     #[test]
     fn test_binary_functions() {
         let df = create_sample_df().unwrap();
-        let mut context = SQLContext::try_new().unwrap();
+        let mut context = SQLContext::new();
         context.register("df", df.clone().lazy());
         let sql = r#"
             SELECT 
@@ -244,7 +246,7 @@ mod test {
     #[test]
     fn test_null_exprs() {
         let df = create_sample_df().unwrap();
-        let mut context = SQLContext::try_new().unwrap();
+        let mut context = SQLContext::new();
         context.register("df", df.clone().lazy());
         let sql = r#"
             SELECT 
@@ -279,7 +281,7 @@ mod test {
         }
         .unwrap();
 
-        let mut context = SQLContext::try_new().unwrap();
+        let mut context = SQLContext::new();
         context.register("df", df.clone().lazy());
         let sql = r#"
             SELECT 
@@ -303,7 +305,7 @@ mod test {
             "a" => [1.0]
         }
         .unwrap();
-        let mut context = SQLContext::try_new().unwrap();
+        let mut context = SQLContext::new();
         context.register("df", df.clone().lazy());
         let sql = r#"
             SELECT 
@@ -352,7 +354,7 @@ mod test {
         .unwrap()
         .lazy();
         let sql = r#"SELECT a, FLOOR(a) AS floor, CEIL(a) AS ceil FROM df"#;
-        let mut context = SQLContext::try_new().unwrap();
+        let mut context = SQLContext::new();
         context.register("df", df.clone());
 
         let df_sql = context.execute(sql).unwrap().collect().unwrap();
@@ -373,7 +375,7 @@ mod test {
             "a" => &["foo", "xxxbarxxx", "---bazyyy"]
         }
         .unwrap();
-        let mut context = SQLContext::try_new().unwrap();
+        let mut context = SQLContext::new();
         context.register("df", df.clone().lazy());
         let sql = r#"
             SELECT 
@@ -448,7 +450,7 @@ mod test {
     #[test]
     fn test_agg_functions() {
         let df = create_sample_df().unwrap();
-        let mut context = SQLContext::try_new().unwrap();
+        let mut context = SQLContext::new();
         context.register("df", df.clone().lazy());
         let sql = r#"
             SELECT 
@@ -489,7 +491,7 @@ mod test {
     #[test]
     fn create_table() {
         let df = create_sample_df().unwrap();
-        let mut context = SQLContext::try_new().unwrap();
+        let mut context = SQLContext::new();
         context.register("df", df.clone().lazy());
         let sql = r#"
             CREATE TABLE df2 AS
@@ -517,7 +519,7 @@ mod test {
         }
         .unwrap();
 
-        let mut context = SQLContext::try_new().unwrap();
+        let mut context = SQLContext::new();
         context.register("df", df.clone().lazy());
         let sql = r#"SELECT * FROM df WHERE value < -1"#;
         let df_sql = context.execute(sql).unwrap().collect().unwrap();
@@ -535,7 +537,7 @@ mod test {
         }
         .unwrap();
 
-        let mut context = SQLContext::try_new().unwrap();
+        let mut context = SQLContext::new();
         context.register("df", df.clone().lazy());
         let sql = r#"SELECT * FROM df WHERE -value < 1"#;
         let df_sql = context.execute(sql).unwrap().collect().unwrap();
@@ -545,7 +547,7 @@ mod test {
     }
 
     fn assert_sql_to_polars(df: &DataFrame, sql: &str, f: impl FnOnce(LazyFrame) -> LazyFrame) {
-        let mut context = SQLContext::try_new().unwrap();
+        let mut context = SQLContext::new();
         context.register("df", df.clone().lazy());
         let df_sql = context.execute(sql).unwrap().collect().unwrap();
         let df_pl = f(df.clone().lazy()).collect().unwrap();
@@ -596,7 +598,7 @@ mod test {
     #[test]
     #[cfg(feature = "csv")]
     fn read_csv_tbl_func() {
-        let mut context = SQLContext::try_new().unwrap();
+        let mut context = SQLContext::new();
         let sql = r#"
             CREATE TABLE foods1 AS
             SELECT *
@@ -618,7 +620,7 @@ mod test {
     #[test]
     #[cfg(feature = "csv")]
     fn read_csv_tbl_func_inline() {
-        let mut context = SQLContext::try_new().unwrap();
+        let mut context = SQLContext::new();
         let sql = r#"
             SELECT foods1.category
             FROM read_csv('../../examples/datasets/foods1.csv') as foods1"#;
@@ -635,7 +637,7 @@ mod test {
     #[test]
     #[cfg(feature = "csv")]
     fn read_csv_tbl_func_inline_2() {
-        let mut context = SQLContext::try_new().unwrap();
+        let mut context = SQLContext::new();
         let sql = r#"
             SELECT category
             FROM read_csv('../../examples/datasets/foods1.csv')"#;
@@ -653,7 +655,7 @@ mod test {
     #[test]
     #[cfg(feature = "parquet")]
     fn read_parquet_tbl() {
-        let mut context = SQLContext::try_new().unwrap();
+        let mut context = SQLContext::new();
         let sql = r#"
             CREATE TABLE foods1 AS
             SELECT *
@@ -675,7 +677,7 @@ mod test {
     #[test]
     #[cfg(feature = "ipc")]
     fn read_ipc_tbl() {
-        let mut context = SQLContext::try_new().unwrap();
+        let mut context = SQLContext::new();
         let sql = r#"
             CREATE TABLE foods1 AS
             SELECT *
@@ -698,7 +700,7 @@ mod test {
     #[test]
     #[cfg(feature = "csv")]
     fn iss_7436() {
-        let mut context = SQLContext::try_new().unwrap();
+        let mut context = SQLContext::new();
         let sql = r#"
             CREATE TABLE foods AS
             SELECT *
@@ -736,7 +738,7 @@ mod test {
     #[test]
     #[cfg(feature = "csv")]
     fn iss_7437() -> PolarsResult<()> {
-        let mut context = SQLContext::try_new()?;
+        let mut context = SQLContext::new();
         let sql = r#"
             CREATE TABLE foods AS
             SELECT *
@@ -767,7 +769,7 @@ mod test {
     #[test]
     #[cfg(feature = "ipc")]
     fn test_groupby_2() -> PolarsResult<()> {
-        let mut context = SQLContext::try_new()?;
+        let mut context = SQLContext::new();
         let sql = r#"
         CREATE TABLE foods AS
         SELECT *
