@@ -7,7 +7,7 @@ import numpy as np
 import pytest
 
 import polars as pl
-from polars.exceptions import PanicException
+from polars.exceptions import PolarsPanicError
 from polars.testing import assert_frame_equal
 
 
@@ -141,7 +141,7 @@ def test_scan_csv_schema_new_columns_dtypes(
     )
 
     # expect same number of column names as there are columns in the file
-    with pytest.raises(PanicException, match="should be equal"):
+    with pytest.raises(PolarsPanicError, match="should be equal"):
         pl.scan_csv(
             file_path,
             dtypes=[pl.Utf8, pl.Utf8],
